bayespy.nodes.SumMultiply
=========================

.. currentmodule:: bayespy.nodes

.. autoclass:: SumMultiply

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~SumMultiply.__init__
      ~SumMultiply.add_plate_axis
      ~SumMultiply.broadcasting_multiplier
      ~SumMultiply.delete
      ~SumMultiply.get_mask
      ~SumMultiply.get_moments
      ~SumMultiply.get_parameters
      ~SumMultiply.get_shape
      ~SumMultiply.has_plotter
      ~SumMultiply.lower_bound_contribution
      ~SumMultiply.move_plates
      ~SumMultiply.plot
      ~SumMultiply.set_plotter
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: generated/
   
      ~SumMultiply.plates
      ~SumMultiply.plates_multiplier
   
   